@@ -40,6 +40,11 @@ from os import environ
 from gettext import textdomain, bindtextdomain
 from gettext import gettext as _
 
+# XDG
+from xdg.BaseDirectory import (save_cache_path, save_config_path,
+                               save_data_path, xdg_cache_home,
+                               xdg_config_home, xdg_data_home)
+
 
 # ------------------------------------------------------------------------------
 #   Launcher
@@ -93,6 +98,31 @@ def make_directory(path, mode=0o755, make_parents=True):
     return False
 
 
+def make_user_directory(directory, xdg_method):
+    """ Generate an user directory
+
+    Parameters
+    ----------
+    directory : str
+        User directory path to generate
+    xdg_method : func
+        Specific xdg.BaseDirectory method to use when directory is null
+
+    Returns
+    -------
+    pathlib.Path
+        Generated directory path
+    """
+
+    if directory is None:
+        return Path(xdg_method(GEM.Instance)).expanduser()
+
+    path = Path(directory).expanduser().joinpath(GEM.Instance)
+    path.mkdir(mode=0o755, parents=True, exist_ok=True)
+
+    return path
+
+
 def init_localization(egg_name):
     """ Initialize application localization
 
@@ -224,13 +254,147 @@ def init_configuration(gem):
                     gem.logger.debug(f"Copy {filename} to {new_path}")
 
 
-def main():
-    """ Main launcher
+def init_cache_directory(directory, clean_cache):
+    """ Initialize Geode-GEM dedicated user cache directory
+
+    Parameters
+    ----------
+    directory : str
+        Cache directory path
+    clean_cache : bool
+        Remove files from cache if directory exists
+
+    Notes
+    -----
+    By default, this directory if often ~/.cache/gem
     """
 
+    setattr(Folders, "CACHE", directory)
+
+    if Folders.CACHE.exists() and clean_cache:
+
+        if Folders.CACHE.is_dir():
+            rmtree(Folders.CACHE)
+
+        Folders.CACHE.mkdir(mode=0o755, parents=True, exist_ok=True)
+
+
+def launch_interface(gem, cache):
+    """ Start main interface
+
+    Parameters
+    ----------
+    gem : geode_gem.engine.api.GEM
+        GEM API instance
+    cache : pathlib.Path
+        Cache directory path
+
+    Returns
+    -------
+    bool
+        False if the interface was launched successfully, True otherwise
+    """
+
+    if "DISPLAY" not in environ or len(environ.get("DISPLAY")) == 0:
+        getLogger(gem.Instance).critical(
+            "Cannot launch GEM without display")
+
+        return True
+
+    if not gem.is_locked():
+        # Initialize main configuration files
+        init_configuration(gem)
+
+        getLogger(gem.Instance).info(f"Start GEM with PID {gem.pid}")
+
+        # Start splash
+        from geode_gem.ui.splash import Splash
+        Splash(gem)
+
+        # Start interface
+        from geode_gem.ui.interface import MainWindow
+        MainWindow(gem, cache)
+
+        # Remove lock
+        gem.free_lock()
+
+    else:
+        getLogger(gem.Instance).critical(
+            f"GEM is already running with PID {gem.pid}")
+
+        from geode_gem.ui.splash import Message
+        message = Message(
+            _("An instance already exists"),
+            _("GEM is already running with PID %s") % gem.pid)
+        message.run()
+
+    return False
+
+
+def start_geode_gem(cache=None, config=None, local=None,
+                    clean_cache=False, debug=False):
+    """ Generate Geode-GEM API object and launch main interface
+
+    Parameters
+    ----------
+    cache : None
+        Geode-GEM cache directory path (Default: None)
+    config : None
+        Geode-GEM config directory path (Default: None)
+    local : None
+        Geode-GEM data directory path (Default: None)
+    clean_cache : bool
+        Ensure to clean Geode-GEM directory cache (Default: False)
+    debug : bool
+        Activate debug flag (Default: False)
+
+    Returns
+    -------
+    bool
+        False if the process was launched successfully, True otherwise
+    """
+
+    process_status = False
+
     # Initialize localization
     init_localization("geode_gem")
 
+    # Initialize user application directories
+    cache = make_user_directory(cache, save_cache_path)
+    config = make_user_directory(config, save_config_path)
+    local = make_user_directory(local, save_data_path)
+
+    # Manage cache directory
+    init_cache_directory(cache, clean_cache)
+
+    try:
+        gem = GEM(config, local, debug)
+
+        process_status = launch_interface(gem, cache)
+
+    except ImportError:
+        getLogger("gem").exception("An error occur during modules importation")
+        process_status = True
+
+    except KeyboardInterrupt:
+        getLogger("gem").warning("Terminate by keyboard interrupt")
+        process_status = True
+
+    except Exception:
+        getLogger("gem").exception("An error occur during execution")
+        process_status = True
+
+    # Remove lock when an error occurs
+    if process_status:
+        gem.free_lock()
+
+    return process_status
+
+
+def main():
+    """ Main launcher
+    """
+
     # Initialize environment
     init_environment()
 
@@ -260,21 +424,21 @@ def main():
     parser_api.add_argument(
         "--cache",
         action="store",
-        metavar="FOLDER",
-        default=Folders.Default.CACHE,
-        help=f"set cache folder (default: {Folders.Default.CACHE})")
+        metavar="DIR",
+        default=None,
+        help=f"set cache folder (default: {xdg_cache_home})")
     parser_api.add_argument(
         "--config",
         action="store",
-        metavar="FOLDER",
-        default=Folders.Default.CONFIG,
-        help=f"set configuration folder (default: {Folders.Default.CONFIG})")
+        metavar="DIR",
+        default=None,
+        help=f"set configuration folder (default: {xdg_config_home})")
     parser_api.add_argument(
         "--local",
         action="store",
-        metavar="FOLDER",
-        default=Folders.Default.LOCAL,
-        help=f"set data folder (default: {Folders.Default.LOCAL})")
+        metavar="DIR",
+        default=None,
+        help=f"set data folder (default: {xdg_data_home})")
 
     parser_maintenance = parser.add_argument_group("maintenance arguments")
     parser_maintenance.add_argument(
@@ -282,87 +446,7 @@ def main():
         action="store_true",
         help="clean icons cache directory")
 
-    arguments = parser.parse_args()
-
-    # ----------------------------------------
-    #   Cache directory
-    # ----------------------------------------
-
-    setattr(Folders, "CACHE",
-            Path(arguments.cache, "gem").expanduser().resolve())
-    make_directory(Folders.CACHE)
-
-    if Folders.CACHE.exists() and arguments.clean_cache:
-
-        if Folders.CACHE.is_dir():
-            rmtree(Folders.CACHE)
-
-        if not Folders.CACHE.exists():
-            Folders.CACHE.mkdir(mode=0o755, parents=True)
-
-    # ----------------------------------------
-    #   Launch interface
-    # ----------------------------------------
-
-    process_status = False
-
-    try:
-        gem = GEM(arguments.config, arguments.local, arguments.debug)
-
-        # Set cache directory
-        cache_path = Folders.Default.CACHE.joinpath(gem.Instance)
-
-        # Check display settings
-        if "DISPLAY" in environ and environ.get("DISPLAY"):
-
-            if not gem.is_locked():
-                # Initialize main configuration files
-                init_configuration(gem)
-
-                getLogger(gem.Instance).info(f"Start GEM with PID {gem.pid}")
-
-                # Start splash
-                from geode_gem.ui.splash import Splash
-                Splash(gem)
-
-                # Start interface
-                from geode_gem.ui.interface import MainWindow
-                MainWindow(gem, cache_path)
-
-                # Remove lock
-                gem.free_lock()
-
-            else:
-                getLogger(gem.Instance).critical(
-                    f"GEM is already running with PID {gem.pid}")
-
-                from geode_gem.ui.splash import Message
-                message = Message(
-                    _("An instance already exists"),
-                    _("GEM is already running with PID %s") % gem.pid)
-                message.run()
-
-        else:
-            getLogger(gem.Instance).critical(
-                "Cannot launch GEM without display")
-
-    except ImportError:
-        getLogger("gem").exception("An error occur durint modules importation")
-        process_status = True
-
-    except KeyboardInterrupt:
-        getLogger("gem").warning("Terminate by keyboard interrupt")
-        process_status = True
-
-    except Exception:
-        getLogger("gem").exception("An error occur during execution")
-        process_status = True
-
-    # Remove lock when an error occurs
-    if process_status:
-        gem.free_lock()
-
-    return process_status
+    return start_geode_gem(**vars(parser.parse_args()))
 
 
 if __name__ == "__main__":
