@@ -43,6 +43,9 @@ import logging
 
 from logging.config import fileConfig
 
+# Python
+from copy import deepcopy
+
 # System
 from os import getpid
 from os import name as os_name
@@ -56,7 +59,7 @@ from sys import exit as sys_exit
 class GEM(object):
 
     Instance = "gem"
-    Version = "0.11.2"
+    Version = "0.12.0"
 
     Log = "gem.log"
     Logger = "log.conf"
@@ -122,8 +125,8 @@ class GEM(object):
         #   Initialize filepaths
         # ----------------------------------------
 
-        self.__config = config.joinpath(GEM.Instance).expanduser()
-        self.__local = local.joinpath(GEM.Instance).expanduser()
+        self.__config = config.expanduser()
+        self.__local = local.expanduser()
 
         self.__log_path = self.__local.joinpath(f"{GEM.Instance}.log")
         self.__lock_path = self.__local.joinpath(".lock")
@@ -258,6 +261,8 @@ class GEM(object):
 
             # Check current GEM version
             version = self.database.select("gem", "version")
+            if version is not None:
+                version = version[0]
 
             # Check Database inner version and GEM version
             if not version == GEM.Version:
@@ -421,6 +426,7 @@ class GEM(object):
                 games = previous_database.select("games", ['*'])
 
                 if games is not None:
+                    games = games[0]
 
                     # Get current table columns
                     old_columns_name = previous_database.get_columns("games")
@@ -703,13 +709,13 @@ class GEM(object):
         if emulator is not None and len(emulator) > 0:
 
             if emulator in self.__data["emulators"].keys():
-                return self.__data["emulators"].get(emulator, None)
+                return deepcopy(self.__data["emulators"].get(emulator, None))
 
             # Check if emulator use name instead of identifier
             identifier = generate_identifier(emulator)
 
             if identifier in self.__data["emulators"].keys():
-                return self.__data["emulators"].get(identifier, None)
+                return deepcopy(self.__data["emulators"].get(identifier, None))
 
         return None
 
@@ -746,7 +752,7 @@ class GEM(object):
 
         self.__data["emulators"][emulator.id] = emulator
 
-        return emulator
+        return deepcopy(emulator)
 
     def update_emulator(self, emulator):
         """ Update a specific emulator
@@ -779,38 +785,44 @@ class GEM(object):
 
         del self.__data["emulators"][emulator]
 
-    def rename_emulator(self, previous, identifier):
-        """ Rename an emulator and all associate objects (consoles and games)
+    def replace_emulator(self, identifier, emulator):
+        """ Replace an emulator from API storage and Console emulator attribute
 
         Parameters
         ----------
-        previous : str
-            Emulator previous identifier
         identifier : str
-            Emulator new identifier
+            Emulator identifier to replace
+        emulator : geode_gem.engine.emulator.Emulator
+            Emulator object
 
         Raises
         ------
+        TypeError
+            when emulator argument is not an Emulator object type
         IndexError
-            if emulator not exists
+            when identifier cannot be find in emulators storage list
         """
 
-        # Avoid to rename an emulator with the same name :D
-        if not previous == identifier:
+        if not isinstance(emulator, Emulator):
+            raise TypeError(f"Cannot use emulator argument, must be a "
+                            f"{repr(Emulator)} object")
 
-            if identifier not in self.__data["emulators"].keys():
-                raise IndexError(
-                    f"Cannot access to {identifier} in emulators list")
+        # No need to rename the emulator
+        if identifier == emulator.id:
+            return
 
-            # Retrieve emulator object
-            self.__rename[previous] = self.__data["emulators"][identifier]
+        emulators = self.__data.get("emulators")
+        if identifier not in emulators:
+            raise IndexError(f"Cannot find '{identifier}' in emulators list")
 
-            # Update consoles which use previous emulator
-            for console_identifier in self.__data["consoles"].keys():
-                console = self.__data["consoles"][console_identifier]
+        emulators[emulator.id] = emulator
+        # Remove the previous emulator from storage
+        del emulators[identifier]
 
-                if console is not None and console.emulator.id == previous:
-                    console.emulator = self.__rename[previous]
+        # Update consoles which use previous emulator
+        for console in self.__data.get("consoles").values():
+            if console.emulator.id == identifier:
+                console.emulator = emulator
 
     @property
     def consoles(self):
@@ -859,13 +871,13 @@ class GEM(object):
         if console is not None and len(console) > 0:
 
             if console in self.__data["consoles"].keys():
-                return self.__data["consoles"].get(console, None)
+                return deepcopy(self.__data["consoles"].get(console, None))
 
             # Check if console use name instead of identifier
             identifier = generate_identifier(console)
 
             if identifier in self.__data["consoles"].keys():
-                return self.__data["consoles"].get(identifier, None)
+                return deepcopy(self.__data["consoles"].get(identifier, None))
 
         return None
 
@@ -904,7 +916,7 @@ class GEM(object):
 
         self.__data["consoles"][console.id] = console
 
-        return console
+        return deepcopy(console)
 
     def update_console(self, console):
         """ Update a specific console
@@ -937,6 +949,40 @@ class GEM(object):
 
         del self.__data["consoles"][console]
 
+    def replace_console(self, identifier, console):
+        """ Replace a console from API storage
+
+        Parameters
+        ----------
+        identifier : str
+            Console identifier to replace
+        console : geode_gem.engine.console.Console
+            Console object
+
+        Raises
+        ------
+        TypeError
+            when console argument is not a Console object type
+        IndexError
+            when identifier cannot be find in consoles storage list
+        """
+
+        if not isinstance(console, Console):
+            raise TypeError(f"Cannot use console argument, must be a "
+                            f"{repr(Console)} object")
+
+        # No need to rename the console
+        if identifier == console.id:
+            return
+
+        consoles = self.__data.get("consoles")
+        if identifier not in consoles:
+            raise IndexError(f"Cannot find '{identifier}' in consoles list")
+
+        consoles[console.id] = console
+        # Remove the previous console from storage
+        del consoles[identifier]
+
     @property
     def environment(self):
         """ Return environment dict
@@ -1067,17 +1113,18 @@ class GEM(object):
         self.database.modify("games", data, {"filename": game.path.name})
 
         # Update game environment variables
-        self.logger.debug(f"Update {game.name} environment variables")
+        if self.environment is not None:
+            self.logger.debug(f"Update {game.name} environment variables")
 
-        self.environment.remove_section(game.id)
+            self.environment.remove_section(game.id)
 
-        if len(game.environment) > 0:
-            self.environment.add_section(game.id)
+            if len(game.environment) > 0:
+                self.environment.add_section(game.id)
 
-            for key, value in game.environment.items():
-                self.environment.set(game.id, key.upper(), value)
+                for key, value in game.environment.items():
+                    self.environment.set(game.id, key.upper(), value)
 
-        self.environment.update()
+            self.environment.update()
 
     def delete_game(self, game):
         """ Delete a specific game
@@ -1105,8 +1152,9 @@ class GEM(object):
             self.database.remove("games", {"filename": game.path.name})
 
         # Update game environment variables
-        self.logger.debug(f"Remove {game.name} environment variables")
+        if self.environment is not None:
+            self.logger.debug(f"Remove {game.name} environment variables")
 
-        self.environment.remove_section(game.id)
+            self.environment.remove_section(game.id)
 
-        self.environment.update()
+            self.environment.update()
