@@ -130,10 +130,10 @@ class Console(object):
         if not self.name and self.path:
             setattr(self, "name", self.path.stem)
 
-        setattr(self, "id", generate_identifier(self.name))
-
-        if not self.name:
-            setattr(self, "name", self.id)
+        if len(self.name) > 0:
+            setattr(self, "id", generate_identifier(self.name))
+        else:
+            setattr(self, "id", None)
 
     def __len__(self):
         """ Retrieve console filtered files number
@@ -192,6 +192,12 @@ class Console(object):
 
         # Retrieve files from games directory
         for filename in self.__files_cache:
+
+            # Ignore missing file since latest forced reload
+            if not filename.exists() and filename in self.__files_cache:
+                self.__files_cache.remove(filename)
+                continue
+
             self.add_game(filename)
 
     def add_game(self, filename):
