@@ -21,8 +21,9 @@
 from pathlib import Path
 
 # GEM
-from geode_gem.engine.utils import get_binary_path
-from geode_gem.engine.utils import generate_identifier
+from geode_gem.engine.utils import (get_binary_path,
+                                    generate_identifier,
+                                    glob_escape)
 
 # System
 from shlex import split as shlex_split
@@ -83,7 +84,10 @@ class Emulator(object):
 
                 setattr(self, key, path)
 
-        setattr(self, "id", generate_identifier(self.name))
+        if len(self.name) > 0:
+            setattr(self, "id", generate_identifier(self.name))
+        else:
+            setattr(self, "id", None)
 
     def __get_content(self, attribute, game):
         """ Get content list for a specific game
@@ -104,16 +108,18 @@ class Emulator(object):
         pattern = str(attribute)
 
         if "<rom_path>" in pattern:
-            pattern = pattern.replace("<rom_path>", str(game.path.parent))
+            pattern = pattern.replace(
+                "<rom_path>", glob_escape(game.path.parent))
 
         if "<lname>" in pattern:
-            pattern = pattern.replace("<lname>", game.path.stem.lower())
+            pattern = pattern.replace(
+                "<lname>", glob_escape(game.path.stem.lower()))
 
         elif "<name>" in pattern:
-            pattern = pattern.replace("<name>", game.path.stem)
+            pattern = pattern.replace("<name>", glob_escape(game.path.stem))
 
         if "<key>" in pattern and len(game.key) > 0:
-            pattern = pattern.replace("<key>", game.key)
+            pattern = pattern.replace("<key>", glob_escape(game.key))
 
         files = list()
 
