@@ -18,7 +18,7 @@
 # ------------------------------------------------------------------------------
 
 # Datetime
-from datetime import date, datetime, timedelta
+from datetime import date, timedelta
 
 # Filesystem
 from pathlib import Path
@@ -29,6 +29,9 @@ from geode_gem.engine.utils import (get_creation_datetime,
                                     parse_timedelta)
 from geode_gem.engine.emulator import Emulator
 
+# Python
+from functools import cached_property
+
 # Regex
 from re import compile as re_compile
 
@@ -51,7 +54,6 @@ class Game(object):
         "play_time": timedelta,
         "last_launch_time": timedelta,
         "last_launch_date": date,
-        "installed": datetime,
         "tags": list,
         "environment": dict,
         "favorite": bool,
@@ -114,9 +116,6 @@ class Game(object):
             if key_type is Emulator or key_type is Path:
                 setattr(self, key, None)
 
-            elif key_type is datetime and key == "installed":
-                setattr(self, key, None)
-
             elif key_type is date:
                 setattr(self, key, date(1, 1, 1))
 
@@ -134,7 +133,7 @@ class Game(object):
         if self.__parent is not None:
             environment = self.__parent.environment
 
-            if self.id in environment.keys():
+            if environment is not None and self.id in environment.keys():
                 for option in environment.options(self.id):
                     self.environment[option.upper()] = environment.get(
                         self.id, option, fallback=str())
@@ -169,7 +168,7 @@ class Game(object):
 
                     if key_type is Path and type(value) is str:
 
-                        path = Path(value).expanduser().resolve()
+                        path = Path(value).expanduser()
                         if len(value) == 0:
                             path = None
 
@@ -286,7 +285,7 @@ class Game(object):
 
         self.__init_attributes()
 
-    @property
+    @cached_property
     def path(self):
         """ Return the game absolute file path
 
@@ -298,7 +297,7 @@ class Game(object):
 
         return self.__path
 
-    @property
+    @cached_property
     def extension(self):
         """ Return extension from filepath
 
@@ -317,6 +316,39 @@ class Game(object):
 
         return extension
 
+    def has_custom_parameters(self, console):
+        """ Check if current game has some custom parameters
+
+        Parameters
+        ----------
+        console : geode_gem.engine.console.Console
+            Console used to check if emulator is the same
+
+        Returns
+        -------
+        bool
+            True is the game has custom parameters, False otherwise
+        """
+
+        return (len(self.default) > 0
+                or len(self.environment) > 0
+                or (console is not None
+                    and console.emulator is not None
+                    and self.emulator is not None
+                    and not console.emulator.id == self.emulator.id))
+
+    @cached_property
+    def installed(self):
+        """ Retrieve Game filepath installed datetime
+
+        Returns
+        -------
+        datetime.datetime
+            Installation date object
+        """
+
+        return self.get_installation_date()
+
     @property
     def screenshots(self):
         """ Get screenshots list
@@ -356,8 +388,8 @@ class Game(object):
 
         return None
 
-    def update_installation_date(self):
+    def get_installation_date(self):
         """ Reload installation date from game file
         """
 
-        setattr(self, "installed", get_creation_datetime(self.__path))
+        return get_creation_datetime(self.__path)
