@@ -96,9 +96,6 @@ class Database(object):
 
         else:
             tables = self.select("sqlite_master", ["name"], {"type": "table"})
-            if not type(tables) is list:
-                tables = [tables]
-
             tables = list(set(self.configuration.sections()) - set(tables))
 
             for table in tables:
@@ -443,8 +440,6 @@ class Database(object):
 
         if value is not None and len(value) == 0:
             return None
-        elif value is not None and len(value) == 1:
-            return value[0]
 
         return value
 
@@ -540,7 +535,7 @@ class Database(object):
 
             result = dict()
             for column in columns:
-                value = values[columns.index(column)]
+                value = values[0][columns.index(column)]
                 if value == "None":
                     value = None
 
@@ -558,8 +553,6 @@ class Database(object):
         """
 
         tables = self.select("sqlite_master", ["name"], {"type": "table"})
-        if not type(tables) is list:
-            tables = [tables]
 
         if not sorted(tables) == sorted(self.configuration.sections()):
             return False
