@@ -20,32 +20,8 @@
 # Filesystem
 from pathlib import Path
 
-# ------------------------------------------------------------------------------
-#   Modules - XDG
-# ------------------------------------------------------------------------------
-
-try:
-    from xdg.BaseDirectory import xdg_data_home
-    from xdg.BaseDirectory import xdg_cache_home
-    from xdg.BaseDirectory import xdg_config_home
-
-except ImportError:
-    from os import environ
-
-    if "XDG_DATA_HOME" in environ:
-        xdg_data_home = Path(environ["XDG_DATA_HOME"]).expanduser()
-    else:
-        xdg_data_home = Path.home().joinpath(".local", "share")
-
-    if "XDG_CACHE_HOME" in environ:
-        xdg_cache_home = Path(environ["XDG_CACHE_HOME"]).expanduser()
-    else:
-        xdg_cache_home = Path.home().joinpath(".cache")
-
-    if "XDG_CONFIG_HOME" in environ:
-        xdg_config_home = Path(environ["XDG_CONFIG_HOME"]).expanduser()
-    else:
-        xdg_config_home = Path.home().joinpath(".config")
+# XDG
+from xdg.BaseDirectory import xdg_cache_home, xdg_config_home, xdg_data_home
 
 
 # ------------------------------------------------------------------------------
