@@ -17,9 +17,10 @@
 #  MA 02110-1301, USA.
 # ------------------------------------------------------------------------------
 
-# GEM
-from geode_gem.ui.data import Icons, Folders
+# Geode-GEM
+from geode_gem.ui.data import Icons
 from geode_gem.ui.widgets.window import CommonWindow
+from geode_gem.widgets import GeodeGtk
 
 # GObject
 from gi.repository import Gtk, Pango
@@ -28,10 +29,6 @@ from gi.repository import Gtk, Pango
 from gettext import gettext as _
 
 
-# ------------------------------------------------------------------------------
-#   Class
-# ------------------------------------------------------------------------------
-
 class CleanCacheDialog(CommonWindow):
 
     def __init__(self, parent):
@@ -43,74 +40,51 @@ class CleanCacheDialog(CommonWindow):
             Parent object
         """
 
-        classic_theme = False
-        if parent is not None:
-            classic_theme = parent.use_classic_theme
-
         CommonWindow.__init__(self,
                               parent,
-                              _("Clean icons cache"),
+                              _("Rebuild icons cache"),
                               Icons.Symbolic.FOLDER,
-                              classic_theme)
+                              parent.use_classic_theme)
 
-        # ------------------------------------
-        #   Prepare interface
-        # ------------------------------------
-
-        # Init widgets
+        # Initialize interface
         self.__init_widgets()
-
-        # Start interface
-        self.__start_interface()
+        self.__init_packing()
 
     def __init_widgets(self):
         """ Initialize interface widgets
         """
 
         self.set_size(640, -1)
-
         self.set_spacing(6)
-
         self.set_resizable(True)
 
         # ------------------------------------
-        #   Title
+        #   Labels
         # ------------------------------------
 
-        self.label_title = Gtk.Label()
+        self.box = GeodeGtk.Box(
+            GeodeGtk.Label(
+                set_ellipsize=Pango.EllipsizeMode.END,
+                set_markup="<span weight='bold' size='large'>%s</span>" % (
+                    _("Do you really want to rebuild the icons cache "
+                      "directory?")),
+            ),
+            GeodeGtk.Label(
+                set_ellipsize=Pango.EllipsizeMode.END,
+                set_text=_("This action will ensure to remove icons which are "
+                           "no longer used."),
+                set_style=Gtk.STYLE_CLASS_DIM_LABEL,
+            ),
+            set_border_width=18,
+            set_orientation=Gtk.Orientation.VERTICAL,
+            set_spacing=12,
+        )
 
-        # Properties
-        self.label_title.set_markup(
-            "<span weight='bold' size='large'>%s</span>" % (
-                _("Do you really want to clean icons cache directory ?")))
-        self.label_title.set_use_markup(True)
-        self.label_title.set_halign(Gtk.Align.CENTER)
-        self.label_title.set_ellipsize(Pango.EllipsizeMode.END)
-
-        # ------------------------------------
-        #   Description
-        # ------------------------------------
-
-        self.label_description = Gtk.Label()
-
-        # Properties
-        self.label_description.set_text(str(Folders.CACHE))
-        self.label_description.set_line_wrap(True)
-        self.label_description.set_max_width_chars(8)
-        self.label_description.set_single_line_mode(False)
-        self.label_description.set_justify(Gtk.Justification.FILL)
-        self.label_description.set_line_wrap_mode(Pango.WrapMode.WORD)
-
-        # ------------------------------------
-        #   Integrate widgets
-        # ------------------------------------
-
-        self.pack_start(self.label_title, False, False)
-        self.pack_start(self.label_description, False, False)
-
-    def __start_interface(self):
-        """ Load data and start interface
+    def __init_packing(self):
+        """ Initialize widgets packing in main window
         """
 
+        self.pack_start(self.box, False, False)
+
         self.add_button(_("No"), Gtk.ResponseType.NO)
         self.add_button(_("Yes"), Gtk.ResponseType.YES, Gtk.Align.END)
