@@ -1,5 +1,5 @@
 # ------------------------------------------------------------------------------
-#  Copyleft 2015-2020  PacMiam
+#  Copyleft 2015-2021  PacMiam
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -23,15 +23,7 @@ from geode_gem.ui.widgets.window import CommonWindow
 from geode_gem.ui.widgets.widgets import ListBoxItem, ScrolledListBox
 
 # GObject
-try:
-    from gi import require_version
-    require_version("Gtk", "3.0")
-
-    from gi.repository import Gtk, GdkPixbuf, Pango
-
-except ImportError as error:
-    from sys import exit
-    exit("Cannot found python3-gobject module: %s" % str(error))
+from gi.repository import GdkPixbuf, Gtk, Pango
 
 # Translation
 from gettext import gettext as _
@@ -220,7 +212,7 @@ class DNDConsoleDialog(CommonWindow):
         self.__notebook_pages.clear()
 
         for path, consoles in sorted(self.filepaths.items()):
-            row = DNDGameRow(self.parent, path, consoles)
+            row = DNDGameRow(self.main_parent, path, consoles)
 
             if len(consoles) == 0:
                 self.frame_error.listbox.add(row)
@@ -386,7 +378,8 @@ class DNDSelector(Gtk.Box):
         self.button_consoles.add(self.image_consoles)
         self.button_consoles.set_tooltip_text(
             _("Use this console to each games in the list above"))
-        self.button_consoles.get_style_context().add_class("suggested-action")
+        self.button_consoles.get_style_context().add_class(
+            Gtk.STYLE_CLASS_SUGGESTED_ACTION)
 
         # ----------------------------------------
         #   Manual selection
@@ -440,7 +433,7 @@ class DNDSelector(Gtk.Box):
                 "consoles", 24, console.id, console.icon)
 
             if icon is None:
-                icon = self.dialog.parent.icons.blank(24)
+                icon = self.dialog.parent.icons_blank.get(24)
 
             self.store_consoles.append([icon, console.name, console])
 
@@ -592,7 +585,7 @@ class DNDGameRow(ListBoxItem):
             "consoles", 24, console.id, console.icon)
 
         if icon is None:
-            icon = self.parent.icons.blank(24)
+            icon = self.parent.icons_blank.get(24)
 
         self.image_console.set_from_pixbuf(icon)
 
