@@ -17,8 +17,9 @@
 #  MA 02110-1301, USA.
 # ------------------------------------------------------------------------------
 
-# GEM
+# Geode-GEM
 from geode_gem.ui.widgets.window import CommonWindow
+from geode_gem.widgets import GeodeGtk
 
 # GObject
 from gi.repository import Gtk, Pango
@@ -27,10 +28,6 @@ from gi.repository import Gtk, Pango
 from gettext import gettext as _
 
 
-# ------------------------------------------------------------------------------
-#   Class
-# ------------------------------------------------------------------------------
-
 class MessageDialog(CommonWindow):
 
     def __init__(self, parent, title, message, icon, center=True):
@@ -50,66 +47,46 @@ class MessageDialog(CommonWindow):
             If False, use justify text insted of center (Default: True)
         """
 
-        classic_theme = False
-        if parent is not None:
-            classic_theme = parent.use_classic_theme
-
-        CommonWindow.__init__(self, parent, title, icon, classic_theme)
-
-        # ------------------------------------
-        #   Initialize variables
-        # ------------------------------------
+        CommonWindow.__init__(self,
+                              parent,
+                              title,
+                              icon,
+                              parent.use_classic_theme)
 
+        # Message variables
         self.message = message
-
         self.center = center
 
-        # ------------------------------------
-        #   Prepare interface
-        # ------------------------------------
-
-        # Init widgets
+        # Initialize interface
         self.__init_widgets()
-
-        # Start interface
-        self.__start_interface()
+        self.__init_packing()
 
     def __init_widgets(self):
         """ Initialize interface widgets
         """
 
         self.set_size(480, -1)
-
         self.set_spacing(6)
-
         self.set_resizable(True)
 
-        # ------------------------------------
-        #   Message
-        # ------------------------------------
-
-        text = Gtk.Label()
-
-        # Properties
-        text.set_line_wrap(True)
-        text.set_use_markup(True)
-        text.set_markup(self.message)
-        text.set_line_wrap_mode(Pango.WrapMode.WORD)
-
-        if(self.center):
-            text.set_justify(Gtk.Justification.CENTER)
-
-        else:
-            text.set_justify(Gtk.Justification.FILL)
+        self.grid.set_border_width(18)
 
         # ------------------------------------
-        #   Integrate widgets
+        #   Label
         # ------------------------------------
 
-        self.pack_start(text, True, True)
+        self.label = GeodeGtk.Label(
+            set_justify=(Gtk.Justification.CENTER if self.center
+                         else Gtk.Justification.FILL),
+            set_label=self.message,
+            set_line_wrap=True,
+            set_line_wrap_mode=Pango.WrapMode.WORD,
+        )
 
-    def __start_interface(self):
-        """ Load data and start interface
+    def __init_packing(self):
+        """ Initialize widgets packing in main window
         """
 
+        self.pack_start(self.label, True, True)
+
         self.add_button(_("Close"), Gtk.ResponseType.CLOSE, Gtk.Align.END)
