@@ -17,9 +17,10 @@
 #  MA 02110-1301, USA.
 # ------------------------------------------------------------------------------
 
-# GEM
+# Geode-GEM
 from geode_gem.ui.data import Icons
 from geode_gem.ui.widgets.window import CommonWindow
+from geode_gem.widgets import GeodeGtk
 
 # GObject
 from gi.repository import Gtk, Pango
@@ -28,10 +29,6 @@ from gi.repository import Gtk, Pango
 from gettext import gettext as _
 
 
-# ------------------------------------------------------------------------------
-#   Class
-# ------------------------------------------------------------------------------
-
 class QuestionDialog(CommonWindow):
 
     def __init__(self, parent, title, message):
@@ -47,58 +44,45 @@ class QuestionDialog(CommonWindow):
             Dialog message
         """
 
-        classic_theme = False
-        if parent is not None:
-            classic_theme = parent.use_classic_theme
-
-        CommonWindow.__init__(
-            self, parent, title, Icons.Symbolic.QUESTION, classic_theme)
-
-        # ------------------------------------
-        #   Variables
-        # ------------------------------------
+        CommonWindow.__init__(self,
+                              parent,
+                              title,
+                              Icons.Symbolic.QUESTION,
+                              parent.use_classic_theme)
 
+        # Message variables
         self.message = message
 
-        # ------------------------------------
-        #   Prepare interface
-        # ------------------------------------
-
-        # Init widgets
+        # Initialize interface
         self.__init_widgets()
-
-        # Start interface
-        self.__start_interface()
+        self.__init_packing()
 
     def __init_widgets(self):
         """ Initialize interface widgets
         """
 
         self.set_size(400, -1)
+        self.set_spacing(6)
+        self.set_resizable(True)
+
+        self.grid.set_border_width(18)
 
         # ------------------------------------
         #   Label
         # ------------------------------------
 
-        self.label = Gtk.Label()
+        self.label = GeodeGtk.Label(
+            set_label=self.message,
+            set_line_wrap=True,
+            set_line_wrap_mode=Pango.WrapMode.WORD,
+            set_max_width_chars=10,
+        )
 
-        # Properties
-        self.label.set_line_wrap(True)
-        self.label.set_use_markup(True)
-        self.label.set_max_width_chars(10)
-        self.label.set_line_wrap_mode(Pango.WrapMode.WORD)
-
-        # ------------------------------------
-        #   Integrate widgets
-        # ------------------------------------
+    def __init_packing(self):
+        """ Initialize widgets packing in main window
+        """
 
         self.pack_start(self.label, False, True)
 
-    def __start_interface(self):
-        """ Load data and start interface
-        """
-
         self.add_button(_("No"), Gtk.ResponseType.NO)
         self.add_button(_("Yes"), Gtk.ResponseType.YES, Gtk.Align.END)
-
-        self.label.set_markup(self.message)
