@@ -17,22 +17,18 @@
 #  MA 02110-1301, USA.
 # ------------------------------------------------------------------------------
 
-# GEM
+# Geode-GEM
 from geode_gem.ui.data import Icons
-from geode_gem.ui.utils import on_entry_clear, replace_for_markup
 from geode_gem.ui.widgets.window import CommonWindow
+from geode_gem.widgets import GeodeGtk
 
 # GObject
-from gi.repository import Gtk, Pango
+from gi.repository import Gtk
 
 # Translation
 from gettext import gettext as _
 
 
-# ------------------------------------------------------------------------------
-#   Class
-# ------------------------------------------------------------------------------
-
 class RenameDialog(CommonWindow):
 
     def __init__(self, parent, game):
@@ -46,123 +42,90 @@ class RenameDialog(CommonWindow):
             Game object
         """
 
-        classic_theme = False
-        if parent is not None:
-            classic_theme = parent.use_classic_theme
-
         CommonWindow.__init__(self,
                               parent,
                               _("Rename a game"),
                               Icons.Symbolic.EDITOR,
-                              classic_theme)
-
-        # ------------------------------------
-        #   Variables
-        # ------------------------------------
+                              parent.use_classic_theme)
 
+        # Application objects instances
         self.game = game
 
-        # ------------------------------------
-        #   Prepare interface
-        # ------------------------------------
-
-        # Init widgets
+        # Initialize interface
         self.__init_widgets()
-
-        # Init signals
+        self.__init_packing()
         self.__init_signals()
-
-        # Start interface
-        self.__start_interface()
+        self.__init_interface()
 
     def __init_widgets(self):
         """ Initialize interface widgets
         """
 
         self.set_size(520, -1)
-
         self.set_spacing(6)
-
         self.set_resizable(True)
 
-        # ------------------------------------
-        #   Title
-        # ------------------------------------
-
-        self.label_title = Gtk.Label()
-
-        # Properties
-        self.label_title.set_markup(
-            "<span weight='bold' size='large'>%s</span>" % (
-                replace_for_markup(self.game.name)))
-        self.label_title.set_use_markup(True)
-        self.label_title.set_halign(Gtk.Align.CENTER)
-        self.label_title.set_ellipsize(Pango.EllipsizeMode.END)
+        self.grid.set_border_width(18)
 
         # ------------------------------------
-        #   Options
+        #   Entry
         # ------------------------------------
 
-        self.entry_name = Gtk.Entry()
+        self.entry_name = GeodeGtk.SearchEntry(
+            set_text=self.game.name,
+            set_placeholder_text=self.game.name,
+        )
 
-        # Properties
-        self.entry_name.set_placeholder_text("%s…" % _("New name"))
-        self.entry_name.set_icon_from_icon_name(
-            Gtk.EntryIconPosition.SECONDARY, Icons.Symbolic.CLEAR)
+    def __init_packing(self):
+        """ Initialize widgets packing in main window
+        """
 
-        # ------------------------------------
-        #   Integrate widgets
-        # ------------------------------------
-
-        self.pack_start(self.label_title, False, False)
         self.pack_start(self.entry_name, False, False)
 
+        self.add_button(_("Cancel"), Gtk.ResponseType.CANCEL)
+        self.add_button(_("Apply"), Gtk.ResponseType.APPLY, Gtk.Align.END)
+
     def __init_signals(self):
         """ Initialize widgets signals
         """
 
-        self.entry_name.connect("icon-press", on_entry_clear)
+        signals = {
+            self.entry_name: {
+                "activate": [
+                    {"method": self.validate_name},
+                ],
+            },
+        }
 
-        self.entry_name.connect("changed", self.check_name)
-        self.entry_name.connect("activate", self.validate_name)
+        # Connect widgets
+        self.main_parent.load_signals(signals)
+        # Remove signals storage from memory
+        del signals
 
-    def __start_interface(self):
-        """ Load data and start interface
+    def __init_interface(self):
+        """ Initialize and fill interface widgets
         """
 
-        self.add_button(_("Cancel"), Gtk.ResponseType.CANCEL)
-        self.add_button(_("Apply"), Gtk.ResponseType.APPLY, Gtk.Align.END)
-
         self.set_default_response(Gtk.ResponseType.APPLY)
 
-        if len(self.game.name) > 0:
-            self.entry_name.set_text(self.game.name)
-
-        else:
-            self.set_response_sensitive(Gtk.ResponseType.APPLY, False)
-
-    def get_name(self):
-        """ Retrieve the new name from entry widget
+    @property
+    def data(self):
+        """ Retrieve user selections
 
         Returns
         -------
-        str
-            New name
+        dict
+            User selections from switchs status
         """
 
-        return self.entry_name.get_text()
+        name = self.entry_name.get_text().strip()
 
-    def check_name(self, *args):
-        """ Check the name value to update button sensitivity
-        """
-
-        self.set_response_sensitive(
-            Gtk.ResponseType.APPLY,
-            len(self.entry_name.get_text().strip()) > 0)
+        return {
+            "name": name if len(name) > 0 else self.game.path.name,
+        }
 
     def validate_name(self, *args):
         """ Validate the new name by using the Return key
         """
 
-        if len(self.entry_name.get_text().strip()):
-            self.emit_response(None, Gtk.ResponseType.APPLY)
+        self.emit_response(None, Gtk.ResponseType.APPLY)
