@@ -17,9 +17,6 @@
 #  MA 02110-1301, USA.
 # ------------------------------------------------------------------------------
 
-# Filesystem
-from pathlib import Path
-
 # GEM
 from geode_gem.engine.api import GEM
 from geode_gem.engine.utils import get_binary_path
@@ -36,6 +33,9 @@ from geode_gem.widgets import GeodeGtk
 # GObject
 from gi.repository import Gdk, GdkPixbuf, GLib, Gtk, Pango
 
+# Python
+from copy import deepcopy
+
 # Translation
 from gettext import gettext as _
 
@@ -274,61 +274,6 @@ class PreferencesWindow(CommonWindow):
                         ),
                     ),
                 ),
-                GeodeGtk.StackSection(
-                    _("Editor"),
-                    GeodeGtk.Frame(
-                        GeodeGtk.ListBox(
-                            GeodeGtk.ListBoxItem(
-                                _("Line numbers"),
-                                GeodeGtk.Switch(
-                                    identifier="textview_line_numbers",
-                                ),
-                                description=_("Show line number at beginning "
-                                              "of each line"),
-                            ),
-                            GeodeGtk.ListBoxItem(
-                                _("Tab width"),
-                                GeodeGtk.SpinButton(
-                                    identifier="textview_tab_width",
-                                    set_range=(1.0, 40.0),
-                                    set_increments=(1, 4),
-                                    set_numeric=True,
-                                    set_digits=0,
-                                ),
-                                description=_("Width of a tab character in "
-                                              "spaces"),
-                            ),
-                            GeodeGtk.ListBoxItem(
-                                _("Color scheme"),
-                                GeodeGtk.ComboBox(
-                                    Gtk.ListStore(str, str),
-                                    GeodeGtk.CellRendererText(
-                                        attributes={
-                                            "text": 1,
-                                        },
-                                        set_alignment=(0, 0.5),
-                                    ),
-                                    identifier="textview_color_scheme",
-                                    is_expandable=True,
-                                    is_fillable=True,
-                                    set_id_column=1,
-                                ),
-                                homogeneous=True,
-                            ),
-                            GeodeGtk.ListBoxItem(
-                                _("Font"),
-                                GeodeGtk.FontButton(
-                                    identifier="textview_font",
-                                    is_expandable=True,
-                                    is_fillable=True,
-                                    use_ellipsize=True,
-                                ),
-                                homogeneous=True,
-                            ),
-                        ),
-                    ),
-                    identifier="textview_section",
-                ),
                 GeodeGtk.StackSection(
                     _("Screenshots viewer"),
                     GeodeGtk.Frame(
@@ -369,6 +314,139 @@ class PreferencesWindow(CommonWindow):
                     ),
                 ),
             ),
+            GeodeGtk.StackView(
+                _("Editor"),
+                GeodeGtk.StackSection(
+                    _("Options"),
+                    GeodeGtk.Frame(
+                        GeodeGtk.ListBox(
+                            GeodeGtk.ListBoxItem(
+                                _("Automatic line wrapping"),
+                                GeodeGtk.Switch(
+                                    identifier="textview_wrap_mode",
+                                ),
+                                description=_("Activate the line wrapping when "
+                                              "the content is too long"),
+                            ),
+                            GeodeGtk.ListBoxItem(
+                                _("Highlight current line"),
+                                GeodeGtk.Switch(
+                                    identifier="textview_highlight_line",
+                                ),
+                                description=_("Highlight the current line"),
+                            ),
+                            GeodeGtk.ListBoxItem(
+                                _("Show line numbers"),
+                                GeodeGtk.Switch(
+                                    identifier="textview_line_numbers",
+                                ),
+                                description=_("Show line number at beginning "
+                                              "of each line"),
+                            ),
+                            GeodeGtk.ListBoxItem(
+                                _("Show right margin"),
+                                GeodeGtk.Switch(
+                                    identifier="textview_right_margin",
+                                ),
+                                description=_(
+                                    "Show a margin at the right of the editor"),
+                            ),
+                            GeodeGtk.ListBoxItem(
+                                _("Right margin position"),
+                                GeodeGtk.SpinButton(
+                                    identifier="textview_right_margin_position",
+                                    set_range=(1.0, 256.0),
+                                    set_increments=(1, 4),
+                                    set_numeric=True,
+                                    set_digits=0,
+                                ),
+                                description=_(
+                                    "Right margin position in characters"),
+                            ),
+                        ),
+                    ),
+                ),
+                GeodeGtk.StackSection(
+                    _("Indentation"),
+                    GeodeGtk.Frame(
+                        GeodeGtk.ListBox(
+                            GeodeGtk.ListBoxItem(
+                                _("Automatic indentation"),
+                                GeodeGtk.Switch(
+                                    identifier="textview_auto_indent",
+                                ),
+                                description=_("New line will be indent with "
+                                              "the same as the previous line"),
+                            ),
+                            GeodeGtk.ListBoxItem(
+                                _("Indent line on tab"),
+                                GeodeGtk.Switch(
+                                    identifier="textview_indent_on_tab",
+                                ),
+                                description=_(
+                                    "The tab key will indent of one level"),
+                            ),
+                            GeodeGtk.ListBoxItem(
+                                _("Use space instead of tab"),
+                                GeodeGtk.Switch(
+                                    identifier="textview_space_instead_of_tab",
+                                ),
+                                description=_("The tab character will be "
+                                              "replace by a group of space "
+                                              "characters"),
+                            ),
+                            GeodeGtk.ListBoxItem(
+                                _("Tab width"),
+                                GeodeGtk.SpinButton(
+                                    identifier="textview_tab_width",
+                                    set_range=(1.0, 40.0),
+                                    set_increments=(1, 4),
+                                    set_numeric=True,
+                                    set_digits=0,
+                                ),
+                                description=_(
+                                    "Width of a tab character in spaces"),
+                            ),
+                        ),
+                    ),
+                ),
+                GeodeGtk.StackSection(
+                    _("Style"),
+                    GeodeGtk.Frame(
+                        GeodeGtk.ListBox(
+                            GeodeGtk.ListBoxItem(
+                                _("Color scheme"),
+                                GeodeGtk.ComboBox(
+                                    Gtk.ListStore(str, str),
+                                    GeodeGtk.CellRendererText(
+                                        attributes={
+                                            "text": 1,
+                                        },
+                                        set_alignment=(0, 0.5),
+                                    ),
+                                    identifier="textview_color_scheme",
+                                    is_expandable=True,
+                                    is_fillable=True,
+                                    set_id_column=0,
+                                    set_row_separator_func=(
+                                        self.check_if_row_is_separator),
+                                ),
+                                homogeneous=True,
+                            ),
+                            GeodeGtk.ListBoxItem(
+                                _("Font"),
+                                GeodeGtk.FontButton(
+                                    identifier="textview_font",
+                                    is_expandable=True,
+                                    is_fillable=True,
+                                    use_ellipsize=True,
+                                ),
+                                homogeneous=True,
+                            ),
+                        ),
+                    ),
+                ),
+            ),
             GeodeGtk.StackView(
                 _("Interface"),
                 GeodeGtk.StackSection(
@@ -1033,12 +1111,54 @@ class PreferencesWindow(CommonWindow):
             #   General - Editor
             # ------------------------------------
 
+            "textview_auto_indent": {
+                "type": Gtk.Switch,
+                "section": "editor",
+                "option": "auto_indent",
+                "fallback": False
+            },
+            "textview_indent_on_tab": {
+                "type": Gtk.Switch,
+                "section": "editor",
+                "option": "indent_on_tab",
+                "fallback": True
+            },
+            "textview_wrap_mode": {
+                "type": Gtk.Switch,
+                "section": "editor",
+                "option": "wrap_mode",
+                "fallback": False
+            },
+            "textview_highlight_line": {
+                "type": Gtk.Switch,
+                "section": "editor",
+                "option": "highlight_current_line",
+                "fallback": True
+            },
             "textview_line_numbers": {
                 "type": Gtk.Switch,
                 "section": "editor",
                 "option": "lines",
                 "fallback": True
             },
+            "textview_right_margin": {
+                "type": Gtk.Switch,
+                "section": "editor",
+                "option": "right_margin",
+                "fallback": False
+            },
+            "textview_right_margin_position": {
+                "type": Gtk.SpinButton,
+                "section": "editor",
+                "option": "right_margin_position",
+                "fallback": 80
+            },
+            "textview_space_instead_of_tab": {
+                "type": Gtk.Switch,
+                "section": "editor",
+                "option": "space_instead_of_tab",
+                "fallback": True
+            },
             "textview_tab_width": {
                 "type": Gtk.SpinButton,
                 "section": "editor",
@@ -1049,7 +1169,7 @@ class PreferencesWindow(CommonWindow):
                 "type": Gtk.ComboBox,
                 "section": "editor",
                 "option": "colorscheme",
-                "fallback": "classic"
+                "fallback": "none"
             },
             "textview_font": {
                 "type": Gtk.FontButton,
@@ -1340,26 +1460,48 @@ class PreferencesWindow(CommonWindow):
 
         return text in model.get_value(row, 3).name.lower()
 
+    def check_if_row_is_separator(self, model: Gtk.TreeModel,
+                                  treeiter: Gtk.TreeIter, *args) -> bool:
+        """ Detect if a specific row in combobox is a separator widget
+
+        Parameters
+        ----------
+        model : gi.repository.Gtk.TreeModel
+            Treeview model which receive signal
+        treeiter : gi.repository.Gtk.TreeIter
+            Treeview iter which will be tested
+
+        Returns
+        -------
+        bool
+            True if treeiter is a separator, False otherwise
+        """
+
+        return model.get_value(treeiter, 0) is None
+
     def save_configuration(self):
         """ Load configuration files and fill widgets
         """
 
+        consoles_objects = self.storages.get("consoles").get("objects")
+        emulators_objects = self.storages.get("emulators").get("objects")
+
         # Remove consoles
         for console in self.api.get_consoles():
-            if console.id not in self.storages["consoles"]["objects"].keys():
+            if console.id not in consoles_objects:
                 self.api.delete_console(console.id)
 
         # Update consoles
-        for console in self.storages["consoles"]["objects"].values():
+        for console in consoles_objects.values():
             self.api.update_console(console)
 
         # Remove emulators
         for emulator in self.api.get_emulators():
-            if emulator.id not in self.storages["emulators"]["objects"].keys():
+            if emulator.id not in emulators_objects:
                 self.api.delete_emulator(emulator.id)
 
         # Update emulators
-        for emulator in self.storages["emulators"]["objects"].values():
+        for emulator in emulators_objects.values():
             self.api.update_emulator(emulator)
 
         # Write emulators and consoles data
@@ -1437,43 +1579,19 @@ class PreferencesWindow(CommonWindow):
         #   Editor
         # ------------------------------------
 
-        visible_widget = False
+        widget = self.sidebar.get_widget("textview_color_scheme")
+        model = widget.get_model()
 
-        try:
-            from gi import require_version
-            require_version("GtkSource", "4")
+        style_scheme_manager = GeodeGtk.StyleSchemeManager()
 
-            from gi.repository.GtkSource import StyleSchemeManager
+        model.append(["none", _("None")])
+        model.append(None)
+        for name in style_scheme_manager.get_scheme_ids():
+            colorscheme = style_scheme_manager.get_scheme(name)
+            model.append([colorscheme.get_id(), colorscheme.get_name()])
 
-            widget = self.sidebar.get_widget("textview_color_scheme")
-
-            model = widget.get_model()
-            for path in StyleSchemeManager().get_search_path():
-                self.logger.debug(
-                    f"Check {path} directory for colorscheme file")
-
-                scheme_path = Path(path).expanduser().resolve()
-                for element in sorted(scheme_path.glob("*.xml")):
-                    model.append([str(element), element.stem])
-
-            widget.set_active_id(
-                self.config.item("editor", "colorscheme", "classic"))
-
-            visible_widget = True
-
-        # Causing by require_version
-        except ValueError:
-            self.logger.warning("Cannot found GtkSource module")
-
-        # Causing by importing GtkSource
-        except ImportError:
-            self.logger.warning("Cannot found GtkSource module")
-
-        except Exception:
-            self.logger.exception("Cannot retrieve style schemes")
-
-        if not visible_widget:
-            self.sidebar.get_widget("textview_section").hide()
+        widget.set_active_id(
+            self.config.item("editor", "colorscheme", "classic"))
 
         # ------------------------------------
         #   Configuration file
@@ -1646,20 +1764,27 @@ class PreferencesWindow(CommonWindow):
         if isinstance(data, Console):
             folder = "consoles"
 
-            path = data.path.expanduser().resolve()
+            path = data.path
+            if path is None:
+                status = Icons.Symbolic.WARNING
 
             # Show a warning icon if the games directory not exists
-            if not path.exists():
-                status = Icons.Symbolic.WARNING
+            else:
+                if not path.expanduser().resolve().exists():
+                    status = Icons.Symbolic.WARNING
 
         elif isinstance(data, Emulator):
             folder = "emulators"
 
-            path = data.binary.expanduser()
+            path = data.binary
+            if path is None:
+                status = Icons.Symbolic.WARNING
 
             # Show a warning icon if the binary not exists
-            if not path.exists() and len(get_binary_path(str(path))) == 0:
-                status = Icons.Symbolic.WARNING
+            else:
+                path = path.expanduser()
+                if not path.exists() and len(get_binary_path(str(path))) == 0:
+                    status = Icons.Symbolic.WARNING
 
         icon = self.main_parent.get_pixbuf_from_cache(
             folder, 48, data.id, data.icon, use_cache=False)
@@ -1837,45 +1962,11 @@ class PreferencesWindow(CommonWindow):
             Object which receive signal
         """
 
-        arguments = list()
-
         if widget.identifier == "button_consoles_add":
-            arguments.append(self.storages["consoles"]["objects"])
-
-            dialog_object, key = ConsolePreferences, "consoles"
+            self.on_edit_element(Console(self.api))
 
         elif widget.identifier == "button_emulators_add":
-            dialog_object, key = EmulatorPreferences, "emulators"
-
-        arguments.append(self.storages["emulators"]["objects"])
-
-        dialog = dialog_object(self, None, *arguments)
-        dialog_response = dialog.run()
-        data = dialog.save()
-
-        if dialog_response == Gtk.ResponseType.APPLY and data is not None:
-            storage_rows = self.storages[key]["rows"]
-            storage_objects = self.storages[key]["objects"]
-
-            if widget.identifier == "button_consoles_add":
-                element = Console(self.api, **data)
-
-                # Specified emulator not exists for the moment
-                if element.emulator is None:
-                    identifier = dialog.combo_emulators.get_active_id()
-
-                    if identifier in storage_objects:
-                        element.emulator = storage_objects[identifier]
-
-            elif widget.identifier == "button_emulators_add":
-                element = Emulator(**data)
-
-            model = self.sidebar.get_widget(key).list_model
-            storage_rows[element.id] = \
-                model.append(self.__on_generate_row(element))
-            storage_objects[element.id] = element
-
-        dialog.destroy()
+            self.on_edit_element(Emulator())
 
     def __on_modify_item(self, widget, *args):
         """ Modify an item in the treeview
@@ -1900,52 +1991,7 @@ class PreferencesWindow(CommonWindow):
         if element is None:
             return False
 
-        previous_id = element.id
-
-        # ----------------------------------------
-        #   Launch dialog
-        # ----------------------------------------
-
-        if isinstance(element, Console):
-            dialog = ConsolePreferences(self,
-                                        element,
-                                        self.storages["consoles"]["objects"],
-                                        self.storages["emulators"]["objects"])
-
-        elif isinstance(element, Emulator):
-            dialog = EmulatorPreferences(
-                self, element, self.storages["emulators"]["objects"])
-
-        dialog_response = dialog.run()
-        data = dialog.save()
-
-        dialog.destroy()
-
-        if not dialog_response == Gtk.ResponseType.APPLY or not len(data):
-            return False
-
-        if isinstance(element, Console):
-            storage = self.storages["consoles"]
-
-        elif isinstance(element, Emulator):
-            storage = self.storages["emulators"]
-
-        for key, value in data.items():
-            setattr(element, key, value)
-
-        row = self.__on_generate_row(element)
-        if not previous_id == element.id:
-            storage["objects"][element.id] = storage["objects"][previous_id]
-            storage["rows"][element.id] = storage["rows"][previous_id]
-
-            del storage["objects"][previous_id]
-            del storage["rows"][previous_id]
-
-        for item in row:
-            treeview.set_value(
-                storage["rows"][element.id], row.index(item), item)
-
-        return True
+        self.on_edit_element(element)
 
     def __on_remove_item(self, widget):
         """ Remove an item in the treeview
@@ -1976,11 +2022,162 @@ class PreferencesWindow(CommonWindow):
         dialog.destroy()
 
         if dialog_response == Gtk.ResponseType.YES:
-            storage = self.storages[treeview.identifier]
-
-            treeview.remove(storage["rows"][element.id])
-
-            del storage["objects"][element.id]
-            del storage["rows"][element.id]
+            self.remove_element_from_treeview(treeview, element)
 
         return True
+
+    def on_edit_element(self, element):
+        """ Modify an element from Consoles or Emulators treeview
+
+        Parameters
+        ----------
+        element : geode_gem.engine.console.Console or
+                  geode_gem.engine.emulator.Emulator
+            Geode-GEM API object which will replace previous object
+        """
+
+        is_modify = element.id is not None
+        previous_id = element.id
+
+        self.window.set_sensitive(False)
+
+        if isinstance(element, Console):
+            identifier = "consoles"
+            dialog = ConsolePreferences(
+                self,
+                element,
+                self.storages.get("consoles").get("objects"),
+                self.storages.get("emulators").get("objects"),
+                self.parent.get_window_size_from_configuration(
+                    "console", 800, 600))
+
+        elif isinstance(element, Emulator):
+            identifier = "emulators"
+            dialog = EmulatorPreferences(
+                self,
+                element,
+                self.storages.get("emulators").get("objects"),
+                self.parent.get_window_size_from_configuration(
+                    "emulator", 800, 600))
+
+        if dialog.run() == Gtk.ResponseType.APPLY:
+            element = dialog.save()
+        else:
+            element = None
+
+        dialog.destroy()
+
+        self.window.set_sensitive(True)
+
+        if element is None:
+            return
+
+        if is_modify:
+            self.rename_element(previous_id, element, identifier)
+
+            self.update_element_from_treestore(element, identifier)
+
+        else:
+            self.add_element_into_treestore(element, identifier)
+
+    def add_element_into_treestore(self, element, identifier):
+        """ Add a new element into Consoles or Emulator treeview model storage
+
+        Parameters
+        ----------
+        element : geode_gem.engine.console.Console or
+                  geode_gem.engine.emulator.Emulator
+            Geode-GEM API object
+        identifier : str
+            Storage identifier used to store element object
+        """
+
+        storages = self.storages.get(identifier)
+
+        model = self.sidebar.get_widget(identifier).list_model
+
+        self.logger.debug(f"Add '{element.id}' into {identifier} treeview")
+
+        objects = storages.get("objects")
+        objects[element.id] = deepcopy(element)
+
+        rows = storages.get("rows")
+        rows[element.id] = model.append(self.__on_generate_row(element))
+
+    def rename_element(self, previous_id, element, identifier):
+        """ Rename an element from Consoles or Emulators treeview
+
+        Parameters
+        ----------
+        previous_id : str
+            Element object previous name
+        element : geode_gem.engine.console.Console or
+                  geode_gem.engine.emulator.Emulator
+            Geode-GEM API object which will replace previous object
+        identifier : str
+            Storage identifier used to store element object
+        """
+
+        if previous_id == element.id:
+            return
+
+        self.logger.debug(f"Rename '{previous_id}' as '{element.id}' into "
+                          f"{identifier} storage")
+
+        storages = self.storages.get(identifier)
+
+        objects = storages.get("objects")
+        objects[element.id] = deepcopy(objects[previous_id])
+        del objects[previous_id]
+
+        rows = storages.get("rows")
+        rows[element.id] = rows[previous_id]
+        del rows[previous_id]
+
+    def remove_element_from_treeview(self, treeview, element):
+        """ Remove an element from Consoles or Emulators treeview
+
+        Parameters
+        ----------
+        treeview : gi.repository.Gtk.TreeView
+            Treeview widget which contains specified element
+        element : geode_gem.engine.console.Console or
+                  geode_gem.engine.emulator.Emulator
+            Geode-GEM API object which will replace previous object
+        """
+
+        storages = self.storages.get(treeview.identifier)
+
+        self.logger.debug(
+            f"Remove '{element.id}' from {treeview.identifier} treeview")
+
+        treeview.remove(storages.get("rows")[element.id])
+
+        del storages["objects"][element.id]
+        del storages["rows"][element.id]
+
+    def update_element_from_treestore(self, element, identifier):
+        """ Update an element from Consoles of Emulators treeview model storage
+
+        Parameters
+        ----------
+        element : geode_gem.engine.console.Console or
+                  geode_gem.engine.emulator.Emulator
+            Geode-GEM API object
+        identifier : str
+            Storage identifier used to store element object
+        """
+
+        treeview = self.sidebar.get_widget(identifier)
+
+        objects = self.storages.get(identifier).get("objects")
+        rows = self.storages.get(identifier).get("rows")
+
+        self.logger.debug(
+            f"Update '{element.id}' row from {identifier} treeview")
+
+        row = self.__on_generate_row(element)
+        for item in row:
+            treeview.set_value(rows[element.id], row.index(item), item)
+
+        objects[element.id] = element
