@@ -41,10 +41,9 @@ from re import findall as re_findall
 from gettext import gettext as _
 from gettext import ngettext
 
+# Typing
+from typing import Tuple
 
-# ------------------------------------------------------------------------------
-#   Misc functions
-# ------------------------------------------------------------------------------
 
 def call_external_application(*command):
     """ Call an external application from operating system
@@ -138,6 +137,33 @@ def generate_blank_icons():
     return storage
 
 
+def get_filename_from_icon_theme(icons_theme, name, size):
+    """ Retrieve filepath from a specific name in icon theme
+
+    Parameters
+    ----------
+    icons_theme : gi.repository.Gtk.IconsTheme
+        Gtk Icons Theme object instance
+    name : str
+        Icon name to search in icon theme
+    size : int
+        Icon size in pixels
+
+    Returns
+    -------
+    str or None
+        Icon filepath if found, None otherwise
+    """
+
+    icon_info = icons_theme.lookup_icon(
+        name, size, Gtk.IconLookupFlags.FORCE_SIZE)
+
+    if icon_info is not None:
+        return icon_info.get_filename()
+
+    return None
+
+
 def get_today_from_datetime(date_object):
     """ Retrieve current time for a specific datetime type
 
@@ -428,3 +454,114 @@ def string_from_time(time_object):
         return ngettext(_("1 minute"), _("%d minutes") % minutes, minutes)
 
     return ngettext(_("1 hour"), _("%d hours") % hours, hours)
+
+
+class PixbufSize:
+    """ Reprensent GdkPixbuf.Pixbuf size for the Geode-GEM viewer
+
+    Attributes
+    ----------
+    height : int
+        The pixbuf height value
+    width : int
+        The pixbuf width value
+    default_size : int
+        Default size which will be used to determine the default zoom level size
+    """
+
+    def __init__(self, pixbuf: GdkPixbuf.Pixbuf, default_size: int):
+        """ Constructor
+
+        Parameters
+        ----------
+        pixbuf : GdkPixbuf.Pixbuf
+            The pixbuf used as reference
+        kwargs : dict
+            Dictionary used to override default attributes
+        """
+
+        self.width = pixbuf.get_width()
+        self.height = pixbuf.get_height()
+
+        self.default_size = default_size
+
+    @property
+    def default_height(self) -> int:
+        """ Retrieve the default height based on default_size attribute
+
+        Returns
+        -------
+        int
+            The default height value for current pixbuf
+
+        Examples
+        --------
+        >>> PixbufSize.default_height
+        600
+        """
+
+        if self.width > self.height:
+            return int((self.height * self.default_size) / self.width)
+
+        return self.default_size
+
+    @property
+    def default_width(self) -> int:
+        """ Retrieve the default width based on default_size attribute
+
+        Returns
+        -------
+        int
+            The default width value for current pixbuf
+
+        Examples
+        --------
+        >>> PixbufSize.default_width
+        800
+        """
+
+        if self.width > self.height:
+            return self.default_size
+
+        return int((self.width * self.default_size) / self.height)
+
+    def get_ratio(self, width: int, height: int) -> Tuple[float, float]:
+        """ Get the ratio where the pixbuf fit in specified width and height
+
+        Parameters
+        ----------
+        width : int
+            Width value to use as reference
+        height : int
+            Height value to use as reference
+
+        Returns
+        -------
+        tuple
+            Fit pixbuf ratio as tuple of float
+
+        Examples
+        --------
+        >>> PixbufSize.get_ratio(1024, 768)
+        (1.28, 1.28)
+        """
+
+        return (float(width / self.default_width),
+                float(height / self.default_height))
+
+    @property
+    def size(self) -> Tuple[int, int]:
+        """ Retrieve the pixbuf size
+
+        Returns
+        -------
+        tuple
+            The pixbuf size as tuple of integer
+
+        Examples
+        --------
+        >>> PixbufSize.size
+        (800, 600)
+        """
+
+        return (self.width, self.height)
