@@ -122,6 +122,23 @@ class CommonGamesView(GeodeGtkCommon, Gtk.ScrolledWindow):
 
             del self.storage[identifier]
 
+    def reset_item(self, identifier, data):
+        """ Reset a specific item in games view
+
+        Parameters
+        ----------
+        identifier : str
+            Treeiter identifier
+        data : list
+            Data structure for specific view
+        """
+
+        if identifier in self.storage:
+            treeiter = self.get_treeiter(identifier)
+
+            for column, value in enumerate(data):
+                self.view.set_value(treeiter, column, value)
+
     def get_treeiter(self, identifier):
         """ Retrieve an item from main storage for a specific identifier
 
@@ -141,10 +158,6 @@ class CommonGamesView(GeodeGtkCommon, Gtk.ScrolledWindow):
 
 class GeodeGEMViews(GeodeGtkCommon, Gtk.Box):
 
-    __target__ = [
-        Gtk.TargetEntry.new("text/uri-list", 0, 1337)
-    ]
-
     class Name(Enum):
 
         LIST = "list"
@@ -187,19 +200,16 @@ class GeodeGEMViews(GeodeGtkCommon, Gtk.Box):
         #   Drag and drop
         # ------------------------------------
 
-        self.drag_dest_set(Gtk.DestDefaults.MOTION | Gtk.DestDefaults.DROP,
-                           self.__target__,
-                           Gdk.DragAction.COPY)
+        self.drag_dest_set(Gtk.DestDefaults.ALL, list(), Gdk.DragAction.COPY)
+        self.drag_dest_add_uri_targets()
 
-        self.view_list.view.drag_source_set(
-            Gdk.ModifierType.BUTTON1_MASK,
-            self.__target__,
-            Gdk.DragAction.COPY)
+        self.treeview.drag_source_set(
+            Gdk.ModifierType.BUTTON1_MASK, list(), Gdk.DragAction.COPY)
+        self.treeview.drag_source_add_uri_targets()
 
-        self.view_grid.view.drag_source_set(
-            Gdk.ModifierType.BUTTON1_MASK,
-            self.__target__,
-            Gdk.DragAction.COPY)
+        self.iconview.drag_source_set(
+            Gdk.ModifierType.BUTTON1_MASK, list(), Gdk.DragAction.COPY)
+        self.iconview.drag_source_add_uri_targets()
 
         # ------------------------------------
         #   Signals
@@ -383,6 +393,20 @@ class GeodeGEMViews(GeodeGtkCommon, Gtk.Box):
         self.view_list.remove_item(identifier)
         self.view_grid.remove_item(identifier)
 
+    def reset_game(self, console, game):
+        """ Reset a game from games views
+
+        Parameters
+        ----------
+        console : geode_gem.engine.console.Console
+            Console instance
+        game : geode_gem.engine.game.Game
+            Game instance
+        """
+
+        self.view_list.reset_item(console, game)
+        self.view_grid.reset_item(console, game)
+
     def set_placeholder_visibility(self, is_visible):
         """ Define placeholder visibility
 
@@ -648,12 +672,32 @@ class GeodeGEMTreeView(CommonGamesView):
             Game instance
         """
 
+        row_data = self.get_item_information(console, game)
+
+        return super().append_item(game.id, row_data)
+
+    def get_item_information(self, console, game):
+        """ Retrieve game information from API object
+
+        Parameters
+        ----------
+        console : geode_gem.engine.console.Console
+            Console instance
+        game : geode_gem.engine.game.Game
+            Game instance
+
+        Returns
+        -------
+        list
+            Item information as list structure
+        """
+
         thumbnail = self.interface.get_pixbuf_from_cache(
-            "games", 22, game.id, game.cover)
-        if not thumbnail or (game.cover and not game.cover.exists()):
+            "games", 22, game.id, game.cover, use_blank=False)
+        if thumbnail is None:
             thumbnail = self.interface.icons_games_views.get("treeview")
 
-        row_data = [
+        return [
             self.interface.get_ui_icon(
                 Columns.List.FAVORITE, game.favorite),
             self.interface.get_ui_icon(
@@ -673,17 +717,15 @@ class GeodeGEMTreeView(CommonGamesView):
             string_from_date(game.installed) if game.installed else None,
             self.interface.get_ui_icon(
                 Columns.List.PARAMETER,
-                not game.emulator == console.emulator or game.default),
+                game.has_custom_parameters(console)),
             self.interface.get_ui_icon(
-                Columns.List.SCREENSHOT, game.screenshots),
+                Columns.List.SCREENSHOT, len(game.screenshots) > 0),
             self.interface.get_ui_icon(
-                Columns.List.SAVESTATE, game.savestates),
+                Columns.List.SAVESTATE, len(game.savestates) > 0),
             game,
             thumbnail,
         ]
 
-        return super().append_item(game.id, row_data)
-
     def on_update_cells(self, column, cell, model, treeiter, *args):
         """ Manage specific columns behavior during games adding
 
@@ -714,6 +756,21 @@ class GeodeGEMTreeView(CommonGamesView):
                 widget.set_sensitive(score >= index)
                 widget.set_property("icon-name", icon_name)
 
+    def reset_item(self, console, game):
+        """ See geode_gem.ui.view.CommonGamesView.reset_item
+
+        Parameters
+        ----------
+        console : geode_gem.engine.console.Console
+            Console instance
+        game : geode_gem.engine.game.Game
+            Game instance
+        """
+
+        row_data = self.get_item_information(console, game)
+
+        return super().reset_item(game.id, row_data)
+
 
 class GeodeGEMIconView(CommonGamesView):
 
@@ -761,9 +818,44 @@ class GeodeGEMIconView(CommonGamesView):
             Game instance
         """
 
+        row_data = self.get_item_information(console, game)
+
+        return super().append_item(game.id, row_data)
+
+    def get_item_information(self, console, game):
+        """ Retrieve game information from API object
+
+        Parameters
+        ----------
+        console : geode_gem.engine.console.Console
+            Console instance
+        game : geode_gem.engine.game.Game
+            Game instance
+
+        Returns
+        -------
+        list
+            Item information as list structure
+        """
+
         thumbnail = self.interface.get_pixbuf_from_cache(
-            "games", 96, game.id, game.cover)
-        if not thumbnail or (game.cover and not game.cover.exists()):
+            "games", 96, game.id, game.cover, use_blank=False)
+        if thumbnail is None:
             thumbnail = self.interface.icons_games_views.get("iconview")
 
-        return super().append_item(game.id, [thumbnail, game.name, game])
+        return [thumbnail, game.name, game]
+
+    def reset_item(self, console, game):
+        """ See geode_gem.ui.view.CommonGamesView.reset_item
+
+        Parameters
+        ----------
+        console : geode_gem.engine.console.Console
+            Console instance
+        game : geode_gem.engine.game.Game
+            Game instance
+        """
+
+        row_data = self.get_item_information(console, game)
+
+        return super().reset_item(game.id, row_data)
