@@ -19,6 +19,7 @@
 
 # GEM
 from geode_gem.ui.data import Icons
+from geode_gem.widgets import GeodeGtk
 
 # GObject
 from gi.repository import Gdk, Gtk, Pango
@@ -111,8 +112,8 @@ class CommonWindow(object):
         self.grid_actions_buttons = Gtk.ButtonBox()
 
         # Properties
-        self.grid.set_spacing(18)
-        self.grid.set_border_width(18)
+        self.grid.set_spacing(12)
+        self.grid.set_border_width(6)
 
         self.grid_actions_buttons.set_spacing(12)
         self.grid_actions_buttons.set_margin_top(6)
@@ -410,6 +411,29 @@ class CommonWindow(object):
 
             self.grid_actions.pack_start(self.button_help, False, False, 0)
 
+    def add_external_link_help(self, title, uri):
+        """ Add a link button to dialog interface
+
+        Parameters
+        ----------
+        label : str
+            External link title
+        uri : str
+            External link URI
+        """
+
+        image = GeodeGtk.Image(
+            set_from_icon_name=(Icons.Symbolic.INTERNET, Gtk.IconSize.BUTTON),
+        )
+
+        linkbutton = GeodeGtk.LinkButton(
+            title,
+            set_image=image,
+            set_uri=uri,
+        )
+
+        self.grid_actions.pack_start(linkbutton, False, False, 0)
+
     def pack_end(self, child, expand=True, fill=True, padding=int()):
         """ Packing child widget into dialog grid
 
