@@ -35,6 +35,8 @@ class CommonBox(GeodeGtkCommon):
 
         Parameters
         ----------
+        subclass : Gtk.Container
+            Subclass widget type
         """
 
         GeodeGtkCommon.__init__(self, subclass, **kwargs)
@@ -56,7 +58,11 @@ class CommonBox(GeodeGtkCommon):
             args = [element]
             if not issubclass(type(self), Gtk.HeaderBar) \
                and method.startswith("pack_"):
-                args.extend([element.is_expandable, element.is_fillable, 0])
+                args.extend([
+                    getattr(element, "is_expandable", True),
+                    getattr(element, "is_fillable", True),
+                    0
+                ])
 
             getattr(self, method)(*args)
             self.append_widget(element)
@@ -64,6 +70,15 @@ class CommonBox(GeodeGtkCommon):
             element.show_all()
 
 
+class GeodeGtkAdjustment(GeodeGtkCommon, Gtk.Adjustment):
+
+    def __init__(self, *args, **kwargs):
+        """ Constructor
+        """
+
+        GeodeGtkCommon.__init__(self, Gtk.Adjustment, **kwargs)
+
+
 class GeodeGtkBox(CommonBox, Gtk.Box):
 
     __setters__ = {
@@ -110,9 +125,6 @@ class GeodeGtkImage(GeodeGtkCommon, Gtk.Image):
 
     def __init__(self, *args, **kwargs):
         """ Constructor
-
-        Parameters
-        ----------
         """
 
         GeodeGtkCommon.__init__(self, Gtk.Image, **kwargs)
@@ -122,7 +134,7 @@ class GeodeGtkLabel(GeodeGtkCommon, Gtk.Label):
 
     __setters__ = {
         "set_use_markup": True,
-        "set_use_underline": True,
+        "set_use_underline": False,
         "set_ellipsize": Pango.EllipsizeMode.NONE,
     }
 
@@ -172,7 +184,26 @@ class GeodeGtkRevealer(CommonBox, Gtk.Revealer):
         CommonBox.__init__(self, Gtk.Revealer, *args, **kwargs)
 
 
-class GeodeGtkScrolledWindow(GeodeGtkCommon, Gtk.ScrolledWindow):
+class GeodeGtkScale(GeodeGtkCommon, Gtk.Scale):
+
+    def __init__(self, *args, **kwargs):
+        """ Constructor
+        """
+
+        GeodeGtkCommon.__init__(self, Gtk.Scale, **kwargs)
+
+        for element in args:
+
+            if isinstance(element, Gtk.Adjustment):
+                self.append_widget(element)
+                self.set_adjustment(element)
+
+        if "marks" in kwargs:
+            for mark in kwargs.get("marks"):
+                self.add_mark(*mark)
+
+
+class GeodeGtkScrolledWindow(CommonBox, Gtk.ScrolledWindow):
 
     def __init__(self, *args, **kwargs):
         """ Constructor
@@ -181,6 +212,19 @@ class GeodeGtkScrolledWindow(GeodeGtkCommon, Gtk.ScrolledWindow):
         CommonBox.__init__(self, Gtk.ScrolledWindow, *args, **kwargs)
 
 
+class GeodeGtkSearchBar(GeodeGtkCommon, Gtk.SearchBar):
+
+    def __init__(self, *args, **kwargs):
+        """ Constructor
+        """
+
+        GeodeGtkCommon.__init__(self, Gtk.SearchBar, **kwargs)
+
+        for element in args:
+            self.append_widget(element)
+            self.add(element)
+
+
 class GeodeGtkSpinner(GeodeGtkCommon, Gtk.Spinner):
 
     def __init__(self, *args, **kwargs):
@@ -203,3 +247,12 @@ class GeodeGtkSwitch(GeodeGtkCommon, Gtk.Switch):
         """
 
         GeodeGtkCommon.__init__(self, Gtk.Switch, **kwargs)
+
+
+class GeodeGtkViewport(CommonBox, Gtk.Viewport):
+
+    def __init__(self, *args, **kwargs):
+        """ Constructor
+        """
+
+        CommonBox.__init__(self, Gtk.Viewport, *args, **kwargs)
